[−][src]Struct surf::RequestBuilder
Request Builder
Provides an ergonomic way to chain the creation of a request.
This is generally accessed as the return value from surf::{method}(),
however Request::builder is also provided.
Examples
use surf::http::{Method, mime::HTML, Url}; let mut request = surf::post("https://httpbin.org/post") .body("<html>hi</html>") .header("custom-header", "value") .content_type(HTML) .build(); assert_eq!(request.take_body().into_string().await.unwrap(), "<html>hi</html>"); assert_eq!(request.method(), Method::Post); assert_eq!(request.url(), &Url::parse("https://httpbin.org/post")?); assert_eq!(request["custom-header"], "value"); assert_eq!(request["content-type"], "text/html;charset=utf-8");
use surf::http::{Method, Url}; let url = Url::parse("https://httpbin.org/post")?; let request = surf::Request::builder(Method::Post, url).build();
Implementations
impl RequestBuilder[src]
pub fn new(method: Method, url: Url) -> Self[src]
Create a new instance.
This method is particularly useful when input URLs might be passed by third parties, and you don't want to panic if they're malformed. If URLs are statically encoded, it might be easier to use one of the shorthand methods instead.
Examples
use surf::http::{Method, Url}; let url = Url::parse("https://httpbin.org/get")?; let req = surf::RequestBuilder::new(Method::Get, url).build();
pub fn header(
self,
key: impl Into<HeaderName>,
value: impl ToHeaderValues
) -> Self[src]
self,
key: impl Into<HeaderName>,
value: impl ToHeaderValues
) -> Self
Sets a header on the request.
Examples
let req = surf::get("https://httpbin.org/get").header("header-name", "header-value").build(); assert_eq!(req["header-name"], "header-value");
pub fn content_type(self, content_type: impl Into<Mime>) -> Self[src]
Sets the Content-Type header on the request.
Examples
let req = surf::post("https://httpbin.org/post").content_type(mime::HTML).build(); assert_eq!(req["content-type"], "text/html;charset=utf-8");
pub fn body(self, body: impl Into<Body>) -> Self[src]
Sets the body of the request.
Examples
use serde_json::json; let mut req = surf::post("https://httpbin.org/post").body(json!({ "any": "Into<Body>"})).build(); assert_eq!(req.take_body().into_string().await.unwrap(), "{\"any\":\"Into<Body>\"}");
pub fn query(self, query: &impl Serialize) -> Result<Self, Error>[src]
Set the URL querystring.
Examples
#[derive(Serialize, Deserialize)] struct Index { page: u32 } let query = Index { page: 2 }; let mut req = surf::get("https://httpbin.org/get").query(&query)?.build(); assert_eq!(req.url().query(), Some("page=2")); assert_eq!(req.as_ref().url().as_str(), "https://httpbin.org/get?page=2");
pub async fn recv_bytes(self) -> Result<Vec<u8>>[src]
Submit the request and get the response body as bytes.
Examples
let bytes = surf::get("https://httpbin.org/get").recv_bytes().await?; assert!(bytes.len() > 0);
pub async fn recv_string(self) -> Result<String>[src]
Submit the request and get the response body as a string.
Examples
let string = surf::get("https://httpbin.org/get").recv_string().await?; assert!(string.len() > 0);
pub async fn recv_json<T: DeserializeOwned>(self) -> Result<T>[src]
Submit the request and decode the response body from json into a struct.
Examples
#[derive(Deserialize, Serialize)] struct Ip { ip: String } let uri = "https://api.ipify.org?format=json"; let Ip { ip } = surf::get(uri).recv_json().await?; assert!(ip.len() > 10);
pub async fn recv_form<T: DeserializeOwned>(self) -> Result<T>[src]
Submit the request and decode the response body from form encoding into a struct.
Errors
Any I/O error encountered while reading the body is immediately returned
as an Err.
If the body cannot be interpreted as valid json for the target type T,
an Err is returned.
Examples
#[derive(Deserialize, Serialize)] struct Body { apples: u32 } let url = "https://api.example.com/v1/response"; let Body { apples } = surf::get(url).recv_form().await?;
pub fn build(self) -> Request[src]
Return the constructed Request.
pub async fn send(__arg0: Self) -> Result<Response>[src]
Create a Client and send the constructed Request from it.